==> mule-runtime-tooling-client-4.1.0-sources.jar: org/mule/tooling/client/internal/ApplicationValueProviderService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.internal;

import org.mule.runtime.api.value.ValueResult;
import org.mule.tooling.client.api.value.provider.ValueProviderRequest;
import org.mule.tooling.client.internal.application.RemoteApplicationInvoker;

/**
 * Implementation for retrieving value providers for applications.
 *
 * @since 4.1
 */
public class ApplicationValueProviderService extends AbstractValueProviderService {

  private RemoteApplicationInvoker remoteApplicationInvoker;

  /**
   * Creates an instance of this service.
   *
   * @param remoteApplicationInvoker {@link RemoteApplicationInvoker} to retrieve values for an Application from Mule Runtime. Non null.
   */
  public ApplicationValueProviderService(
                                         RemoteApplicationInvoker remoteApplicationInvoker) {
    this.remoteApplicationInvoker = remoteApplicationInvoker;
  }

  @Override
  protected ValueResult doGetValue(ValueProviderRequest valueProviderRequest) {
    return remoteApplicationInvoker.evaluateWithRemoteApplication((applicationId,
                                                                   runtimeToolingService) -> runtimeToolingService
                                                                       .getValuesApplication(applicationId,
                                                                                             valueProviderRequest
                                                                                                 .getLocation(),
                                                                                             valueProviderRequest
                                                                                                 .getProviderName()));

  }
}

==> mule-runtime-tooling-client-4.2.2-rc2-sources.jar: org/mule/tooling/client/internal/ApplicationValueProviderService.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.tooling.client.internal;

import org.mule.runtime.api.value.ValueResult;
import org.mule.tooling.client.api.value.provider.ValueProviderRequest;
import org.mule.tooling.client.internal.application.RemoteApplicationInvoker;
import org.mule.tooling.client.internal.serialization.Serializer;

/**
 * Implementation for retrieving value providers for applications.
 *
 * @since 4.1
 */
public class ApplicationValueProviderService extends AbstractValueProviderService {

  private RemoteApplicationInvoker remoteApplicationInvoker;

  /**
   * Creates an instance of this service.
   *
   * @param remoteApplicationInvoker {@link RemoteApplicationInvoker} to retrieve values for an Application from Mule Runtime. Non null.
   */
  public ApplicationValueProviderService(RemoteApplicationInvoker remoteApplicationInvoker, Serializer serializer) {
    super(serializer);
    this.remoteApplicationInvoker = remoteApplicationInvoker;
  }

  @Override
  protected ValueResult doGetValue(ValueProviderRequest valueProviderRequest) {
    return remoteApplicationInvoker.evaluateWithRemoteApplication((applicationId,
                                                                   runtimeToolingService) -> runtimeToolingService
                                                                       .getValuesApplication(applicationId,
                                                                                             valueProviderRequest
                                                                                                 .getLocation(),
                                                                                             valueProviderRequest
                                                                                                 .getProviderName()));

  }
}
